@@ -15,12 +15,12 @@ def get_platform_name(): # pragma: no cover
 def get_distribution(): # pragma: no cover
     """:returns: bunch with the following keys: distname, version, id
     """
-    from bunch import Bunch
+    from munch import Munch
     from platform import linux_distribution
     distname, version, _id = linux_distribution()
     # distname in ['Red Hat Enterprise Linux Server', 'Ubuntu']
     distname = ''.join(distname.split()[:2]).lower()
-    return Bunch(distname=distname, version=version, id=_id.lower())
+    return Munch(distname=distname, version=version, id=_id.lower())
 
 class TestOnUbuntu(unittest.TestCase):
     def _running_on_ubuntu(self):
@@ -108,7 +108,7 @@ class TestUbuntuMock(TestOnUbuntu):
     def _aptitude_show(self):
         from textwrap import dedent
         return Output(stdout=dedent("""
-                                    Package: sg3-utils                       
+                                    Package: sg3-utils
                                     State: {}
                                     Automatically installed: no
                                     Version: 1.30-1
